from mag_tools.model.base_enum import BaseEnum


class ActionType(BaseEnum):
    CLICK = ("click", "单击")
    DOUBLE_CLICK = ("double_click", "双击")
    RIGHT_CLICK = ("right_click", "右键单击")
    CLEAR = ("clear", "清除")
    SUBMIT = ("submit", "提交")
    SEND_KEYS = ("send_keys", "发送按键")
    NONE = ("none", "无操作")



from appium import webdriver
from appium.webdriver import WebElement
from selenium.webdriver import ActionChains

from mag_test.core.app_driver import AppDriver


class EventUtils:
    @staticmethod
    def click(driver:webdriver.Remote, element:WebElement, offset:tuple[int,int]=None):
        if offset:
            offset_x, offset_y = offset
            actions = ActionChains(driver)
            actions.move_to_element_with_offset(element, offset_x, offset_y).click().perform()
        else:
            actions = ActionChains(driver)
            actions.move_to_element(element).click().perform()

    @staticmethod
    def click_checkbox(element:WebElement, value:bool):
        if value and not element.is_selected():
            element.click()
        elif not value and element.is_selected():
            element.click()

    @staticmethod
    def click_window(driver:AppDriver, value:str):
        if value == 'close':
            driver.close()
            driver.quit_app()
        elif value == 'max':
            driver.maximize_window()
        elif value == 'min':
            driver.minimize_window()


from selenium.webdriver.common.by import By
from selenium.webdriver.remote.webelement import WebElement
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC

from mag_test.core.app_driver import AppDriver
from mag_test.model.control_type import ControlType
from mag_test.finder.element_finder_utils import ElementFinderUtils


class TreeUtils:
    @staticmethod
    def expand_all(driver:AppDriver, tree:WebElement):
        try:
            # 查找所有展开按钮
            expand_buttons = ElementFinderUtils.find_element_by_type(tree, 'Expand', ControlType.BUTTON)

            for button in expand_buttons:
                # 点击展开按钮
                button.click()
                # 等待子节点加载完成
                WebDriverWait(driver, 10).until(
                    EC.presence_of_element_located((By.XPATH, './/Button[@content-desc="Expand"]')))
                # 递归展开子节点
                TreeUtils.expand_all(driver, tree)
        except Exception as e:
            print(f"Error expanding nodes: {str(e)}")